==> skypager-project-2.51.3.tgz: package/src/logger.js <==
import { Logger, transports } from 'winston'

export function logger(project, options = {}) {

  if (project.logger) {
    return project.logger
  }

  let debug = require('yargs').argv.debug || false
  let env = project.env

  project.ensurePath('logs')

  let _transports = [
    new transports.File({
      name: `project`,
      filename: project.path('logs', `project.${ project.env }.log`),
      timestamp: true,
      json: false,
      prettyPrint: false,
      maxSize: 1024
    }),
  ]

  if (process.env.SKYPAGER_PRETTY_LOGGING) {
    _transports.push(
    new transports.File({
      name: `project-pretty`,
      filename: project.path('logs', `pretty.${ project.env }.log`),
      timestamp: false,
      json: false,
      prettyPrint: true,
      colorize: true
    }))
  }

  if (options.enableConsole || process.env.SKYPAGER_ENABLE_CONSOLE_LOG) {
    _transports.push(new transports.Console({
      colorize: true,
      prettyPrint: true,
      level: debug ? 'debug' : 'info'
    }))
  }

  defineProperty(project, 'logger', {
    enumerable: false,
    configurable: false,
    value: new Logger({
      level: 'debug',
      transports: _transports
    })
  })

  assign(project, {
    //TODO: define metadata
    _log(level, ...args) {
      project.logger.log(level, ...args)
    },

    debug(...args) {
      project._log('debug', ...args)
    },

    info(...args) {
      project._log('info', ...args)
    },

    log(...args) {
      project._log('info', ...args)
    },

    warn(...args) {
      project._log('warn', ...args)
    },

    error(...args) {
      project._log('error', ...args)
    }

  })

  return project.logger
}

export default logger

const { assign, defineProperty } = Object

==> skypager-project-2.56.0.tgz: package/src/logger.js <==
import { Logger, transports } from 'winston'

export function logger(project, options = {}) {

  if (project.logger) {
    return project.logger
  }

  let debug = require('yargs').argv.debug || false
  let env = project.env

  project.ensurePath('logs')

  let _transports = [
    new transports.File({
      name: `project`,
      filename: project.path('logs', `project.${ project.env }.log`),
      timestamp: true,
      json: false,
      prettyPrint: false,
      maxSize: 1024
    }),
  ]

  if (process.env.SKYPAGER_PRETTY_LOGGING) {
    _transports.push(
    new transports.File({
      name: `project-pretty`,
      filename: project.path('logs', `pretty.${ project.env }.log`),
      timestamp: false,
      json: false,
      prettyPrint: true,
      colorize: true
    }))
  }

  if (options.enableConsole || process.env.SKYPAGER_ENABLE_CONSOLE_LOG === true) {
    _transports.push(new transports.Console({
      name: 'console',
      colorize: true,
      prettyPrint: true,
      level: debug ? 'debug' : 'info'
    }))
  }

  defineProperty(project, 'logger', {
    enumerable: false,
    configurable: false,
    value: new Logger({
      level: 'debug',
      transports: _transports
    })
  })

  assign(project, {
    //TODO: define metadata
    _log(level, ...args) {
      project.logger.log(level, ...args)
    },

    debug(...args) {
      project._log('debug', ...args)
    },

    info(...args) {
      project._log('info', ...args)
    },

    log(...args) {
      project._log('info', ...args)
    },

    warn(...args) {
      project._log('warn', ...args)
    },

    error(...args) {
      project._log('error', ...args)
    }

  })

  return project.logger
}

export default logger

const { assign, defineProperty } = Object
